---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: FennisRobert

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce if applicable**
Provide the script you are running if possible or the lines of code that triggered it.

**Logfile**
By setting `emerge.SImulation('modelname', write_log=True)`, EMerge will dump a logging.log file in `modelname.EMResults/`. You can share this file. Make sure to vet it for potential confidential information and system information you might not want to share. The log file may contain
 - Module version numbers
 - Python version number
 - OS
 - Architecture
 - CPU count

**Additional context**
Add any other context about the problem here.
